@@ -293,7 +293,7 @@ class Sequential():
         else:
             raise ValueError("unknown value for verbose")
     
-    def live_stats(self,live_stats, figure):
+    def live_stats(self,live_stats, figure, F1, F2):
         import matplotlib.pyplot as plt
         if live_stats == 1:
             figure.clear()
@@ -325,12 +325,12 @@ class Sequential():
             plt.subplot(1,1,1)
             if len(self.train_inputs[0,:]) <= 2 and len(self.train_targets[0,:]) == 1:
                 X_set, y_set = self.train_inputs, self.train_targets
-                X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
-                                     np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
+                X1, X2 = np.meshgrid(np.arange(start = X_set[:, F1].min() - 1, stop = X_set[:, F1].max() + 1, step = 0.01),
+                                     np.arange(start = X_set[:, F2].min() - 1, stop = X_set[:, F2].max() + 1, step = 0.01))
                 plt.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
                              alpha = 0.3, cmap = "coolwarm")
                 
-            plt.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
+            plt.scatter(self.train_inputs[:,F1], self.train_inputs[:,F2], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
             
             figure.canvas.draw()
             figure.canvas.flush_events()
@@ -341,12 +341,12 @@ class Sequential():
             plt.subplot(1, 2, 2)
             if len(self.train_inputs[0,:]) <= 2 and len(self.train_targets[0,:]) == 1:
                 X_set, y_set = self.train_inputs, self.train_targets
-                X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
-                                     np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
+                X1, X2 = np.meshgrid(np.arange(start = X_set[:, F1].min() - 1, stop = X_set[:, F1].max() + 1, step = 0.01),
+                                     np.arange(start = X_set[:, F2].min() - 1, stop = X_set[:, F2].max() + 1, step = 0.01))
                 plt.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
                              alpha = 0.3, cmap = "coolwarm")
                 
-            plt.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
+            plt.scatter(self.train_inputs[:,F1], self.train_inputs[:,F2], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
             
             plt.subplot(2,2,1)
             plt.title("Loss Evolution")
@@ -369,7 +369,7 @@ class Sequential():
             figure.canvas.draw()
             figure.canvas.flush_events()
     
-    def fit(self, cost_fn, epochs = 1000, lr = 0.1, momentum = None, verbose = 1, live_stats = 0):
+    def fit(self, cost_fn, epochs = 1000, lr = 0.1, momentum = None, verbose = 1, live_stats = 0, F1=0, F2=1):
         for n in [-1,0,1,2]:
             if live_stats == n:
                 break
@@ -419,7 +419,7 @@ class Sequential():
                 
                 if live_stats != 0:
                     if epoch % update == 0:
-                        self.live_stats(live_stats, figure)
+                        self.live_stats(live_stats, figure, F1, F2)
                             
                 self.verbose(verbose, epoch, epochs, start)
         else:
@@ -436,7 +436,7 @@ class Sequential():
                 
                 if live_stats != 0:
                     if epoch % update == 0:
-                        self.live_stats(live_stats, figure)
+                        self.live_stats(live_stats, figure, F1, F2)
                         
                 self.verbose(verbose, epoch, epochs, start)
         
